@@ -34,7 +34,7 @@ from vectorio import Circle
 from ulab import numpy as np
 
 
-__version__ = "0.8.0"
+__version__ = "0.8.1"
 __repo__ = "https://github.com/adafruit/CircuitPython_uplot.git"
 
 
@@ -55,6 +55,9 @@ class Uplot(displayio.Group):
     :param int padding: padding for the plot box in all directions
     :param bool show_box: select if the plot box is displayed
     :param int background_color: background color in HEX. Defaults to black ``0x000000``
+    :param int box_color: allows to choose the box line color. Defaults to white ''0xFFFFFF``
+    :param int tickx_height: x axes tick height in pixels. Defaults to 8.
+    :param int ticky_height: y axes tick height in pixels. Defaults to 8.
 
     """
 
@@ -67,6 +70,9 @@ class Uplot(displayio.Group):
         padding: int = 25,
         show_box: bool = True,
         background_color: int = 0x000000,
+        box_color: int = 0xFFFFFF,
+        tickx_height: int = 8,
+        ticky_height: int = 8,
     ) -> None:
         if width not in range(50, 481):
             print("Be sure to verify your values. Defaulting to width=100")
@@ -105,7 +111,8 @@ class Uplot(displayio.Group):
 
         self._showtext = False
 
-        self._tickheight = 8
+        self._tickheightx = tickx_height
+        self._tickheighty = ticky_height
         self._tickcolor = 0xFFFFFF
         self._showticks = False
         self._tickgrid = False
@@ -126,7 +133,7 @@ class Uplot(displayio.Group):
 
         self._plot_palette = displayio.Palette(14)
         self._plot_palette[0] = background_color
-        self._plot_palette[1] = 0xFFFFFF
+        self._plot_palette[1] = box_color
         self._plot_palette[2] = self._tickcolor
         self._plot_palette[3] = self._barcolor
         self._plot_palette[4] = 0x149F14  # Pie Chart color 1
@@ -299,7 +306,7 @@ class Uplot(displayio.Group):
                 tick,
                 self._newymin,
                 tick,
-                self._newymin - self._tickheight,
+                self._newymin - self._tickheightx,
                 2,
             )
             if self._showtext:
@@ -311,7 +318,7 @@ class Uplot(displayio.Group):
                 self._plotbitmap,
                 self._newxmin,
                 tick,
-                self._newxmin + self._tickheight,
+                self._newxmin + self._tickheighty,
                 tick,
                 2,
             )
@@ -325,7 +332,7 @@ class Uplot(displayio.Group):
                 tick,
                 self._newymin,
                 tick,
-                self._newymin - self._tickheight // 2,
+                self._newymin - self._tickheightx // 2,
                 2,
             )
         for tick in subticksyrenorm:
@@ -333,7 +340,7 @@ class Uplot(displayio.Group):
                 self._plotbitmap,
                 self._newxmin,
                 tick,
-                self._newxmin + self._tickheight // 2,
+                self._newxmin + self._tickheighty // 2,
                 tick,
                 2,
             )
@@ -344,7 +351,8 @@ class Uplot(displayio.Group):
 
     def tick_params(
         self,
-        tickheight: int = 8,
+        tickx_height: int = 8,
+        ticky_height: int = 8,
         tickcolor: int = 0xFFFFFF,
         tickgrid: bool = False,
         showtext: bool = False,
@@ -352,16 +360,19 @@ class Uplot(displayio.Group):
         """
         Function to set ticks parameters
 
-        :param int tickheight: tick height in pixels
-        :param int tickcolor: tick color in hex
-        :param bool tickgrid: defines if the grid is to be shown
+        :param int tickx_height: X axes tick height in pixels. Defaults to 8
+        :param int ticky_height: Y axes tick height in pixels. Defaults to 8
+        :param int tickcolor: tick color in hex. Defaults to white. ``0xFFFFFF``
+        :param bool tickgrid: defines if the grid is to be shown. Defaults to `False`
+        :param bool showtext: Show Axes text. Defaults to `False`
 
         :return: None
 
         """
 
         self._showticks = True
-        self._tickheight = tickheight
+        self._tickheightx = tickx_height
+        self._tickheighty = ticky_height
         self._plot_palette[2] = tickcolor
         self._tickgrid = tickgrid
         self._showtext = showtext
@@ -439,3 +450,17 @@ class Uplot(displayio.Group):
             text_toplot.anchor_point = anchorpoint
             text_toplot.anchored_position = (x, y)
             self.append(text_toplot)
+
+
+# pylint: disable=missing-class-docstring, too-few-public-methods, invalid-name
+class color:
+    WHITE = 0xFFFFFF
+    BLACK = 0x000000
+    RED = 0xFF0000
+    GREEN = 0x00FF00
+    BLUE = 0x0000FF
+    PURPLE = 0x440044
+    YELLOW = 0xFFFF00
+    ORANGE = 0xFF9933
+    TEAL = 0x158FAD
+    GRAY = 0x808080
